@@ -1,7 +1,8 @@
-vfplotloc <- function( vals, patternMap, vftiles, vfhull, loccol,
-                       xmin = -29, xmax = 29, ymin = -29, ymax = 29,
+vfplotloc <- function( vals, patternMap, loccol, vftiles, vfhull,
+                       xmin, xmax, ymin, ymax,
                        txtfont = "sans", pointsize = 10,
-                       showaxis = FALSE, colaxis = "white" ) {
+                       showaxis = FALSE, colaxis = "black" ) {
+  lumth <- 0.4
 
 # init
   oplt    <- par()$plt
@@ -12,22 +13,16 @@ vfplotloc <- function( vals, patternMap, vftiles, vfhull, loccol,
   par( family = txtfont )
 
   plot( patternMap$xod, patternMap$yod, type = "n", axes = FALSE, xlab = "", ylab = "", asp = 1, xlim = c( xmin, xmax ), ylim = c( ymin, ymax ) )
-  # plot VF values
   plot( vftiles, clipp = vfhull, add = TRUE, close = TRUE, showpoints = FALSE, border = "darkgray", fillcol = rgb( loccol ) )
   if( showaxis ) {
     axis( 1, pos = 0, labels = FALSE, lwd.ticks = 0, at = c( xmin, xmax ), col = colaxis )
     axis( 2, pos = 0, labels = FALSE, lwd.ticks = 0, at = c( ymin, ymax ), col = colaxis )
   }
-  idx <- which( is.na( vals ) )
-  if( length( idx ) > 0 ) {
-    patternMap <- patternMap[-idx,]
-    vals       <- vals[-idx]
-  }
-  coltxt <- rep( "black", length( patternMap$xod ) )
-  coltxt[( loccol$red + loccol$green + loccol$blue ) / 3 < 0.25] <- "white"
+  coltxt <- rep( "grey10", length( patternMap$xod ) )
+  coltxt[( 0.2126 * loccol$red + 0.7152 * loccol$green + 0.0722 * loccol$blue ) < lumth] <- "white"
+  coltxt[loccol$red < 0.1 & loccol$green < 0.6 & loccol$blue < 0.1] <- "white" # ad-hoc patch to make green scale look good
   text( patternMap$xod, patternMap$yod, vals, col = coltxt )
   par( plt    = oplt )
   par( ps     = ops )
   par( family = ofamily )
-
 }
\ No newline at end of file
